==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/SConstantPropagatorAndFolder.h <==
// public class soot.shimple.toolkits.scalar.SConstantPropagatorAndFolder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 619cdbf7231d5387 soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_
#define _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_shimple_ShimpleBody$object;
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$propagateResults$4af8b91149bf93b1(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$removeStmts$3e607ce56d447ae7(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$replaceStmts$4394c106ff2c41eb(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$propagateResults$4af8b91149bf93b1;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$removeStmts$3e607ce56d447ae7;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$replaceStmts$4394c106ff2c41eb;

// Static methods
extern struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$v$36ef23ded1f7a1c4(_jc_env *);

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*propagateResults$4af8b91149bf93b1)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);
	void	(*removeStmts$3e607ce56d447ae7)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);
	void	(*replaceStmts$4394c106ff2c41eb)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs {
	struct _jc_soot_shimple_ShimpleBody$object	*sb;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs {
    _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs {
	jboolean	debug;
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object {
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/SConstantPropagatorAndFolder.h <==
// public class soot.shimple.toolkits.scalar.SConstantPropagatorAndFolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 619cdbf7231d5387 soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_
#define _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_shimple_ShimpleBody$object;
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$propagateResults$4af8b91149bf93b1(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$removeStmts$3e607ce56d447ae7(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$replaceStmts$4394c106ff2c41eb(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$propagateResults$4af8b91149bf93b1;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$removeStmts$3e607ce56d447ae7;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method_info$replaceStmts$4394c106ff2c41eb;

// Static methods
extern struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$method$v$36ef23ded1f7a1c4(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*propagateResults$4af8b91149bf93b1)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*removeStmts$3e607ce56d447ae7)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*replaceStmts$4394c106ff2c41eb)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vmethods	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs {
	struct _jc_soot_shimple_ShimpleBody$object	*sb;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs {
    _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_refs	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs {
	jboolean	debug;
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$sub_nonrefs	soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$object {
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$vtype _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SConstantPropagatorAndFolder_H_ */
